@@ -373,6 +373,57 @@ g_synaptics_is_edge_motion_enabled (GSynaptics *synaptics)
 	}
 }
 
+gdouble
+g_synaptics_accel_delta (GSynaptics *synaptics)
+{
+	GSynapticsPrivate *priv = G_SYNAPTICS_GET_PRIVATE (synaptics);
+	if (!g_synaptics_is_valid(synaptics))
+		return 0;
+
+	if (priv->synclient)
+	{
+		return (gdouble)g_synaptics_get_value_from_synclient ("AccelFactor");
+	}
+	else
+	{
+		return SYNSHM(synaptics)->accl;
+	}
+}
+
+gdouble
+g_synaptics_min_speed_delta (GSynaptics *synaptics)
+{
+	GSynapticsPrivate *priv = G_SYNAPTICS_GET_PRIVATE (synaptics);
+	if (!g_synaptics_is_valid(synaptics))
+		return 0;
+
+	if (priv->synclient)
+	{
+		return (gdouble)g_synaptics_get_value_from_synclient ("MinSpeed");
+	}
+	else
+	{
+		return SYNSHM(synaptics)->min_speed;
+	}
+}
+
+gdouble
+g_synaptics_max_speed_delta (GSynaptics *synaptics)
+{
+	GSynapticsPrivate *priv = G_SYNAPTICS_GET_PRIVATE (synaptics);
+	if (!g_synaptics_is_valid(synaptics))
+		return 0;
+
+	if (priv->synclient)
+	{
+		return (gdouble)g_synaptics_get_value_from_synclient ("MaxSpeed");
+	}
+	else
+	{
+		return SYNSHM(synaptics)->max_speed;
+	}
+}
+
 gboolean
 g_synaptics_is_coasting_enabled (GSynaptics *synaptics)
 {
@@ -576,7 +627,7 @@ g_synaptics_set_sensitivity (GSynaptics *synaptics, gint value)
 	if (!g_synaptics_is_valid(synaptics))
 		return;
 
-  	if ( value < 0 && value > 4)
+  	if ( value < 0 || value > 4)
 		return;
 	
 	if (priv->synclient)
@@ -648,6 +699,72 @@ g_synaptics_set_vertical_scroll_delta (GSynaptics *synaptics, gint delta)
 	}
 }
 
+void
+g_synaptics_set_accel(GSynaptics *synaptics, gdouble delta)
+{
+	GSynapticsPrivate *priv = G_SYNAPTICS_GET_PRIVATE (synaptics);
+	if (!g_synaptics_is_valid(synaptics))
+		return;
+
+	if (priv->synclient)
+	{
+		gchar *command;
+		command = g_strdup_printf ("synclient AccelFactor=%lf",
+			       		   delta);
+		/* TODO check that %lf is  right*/
+		g_spawn_command_line_async (command, NULL);
+		g_free (command);
+	}
+	else
+	{
+		SYNSHM(synaptics)->accl = delta;
+	}
+}
+
+void
+g_synaptics_set_max_speed(GSynaptics *synaptics, gdouble delta)
+{
+	GSynapticsPrivate *priv = G_SYNAPTICS_GET_PRIVATE (synaptics);
+	if (!g_synaptics_is_valid(synaptics))
+		return;
+
+	if (priv->synclient)
+	{
+		gchar *command;
+		command = g_strdup_printf ("synclient MaxSpeed=%lf",
+			       		   delta);
+		/* TODO check that %lf is right */
+		g_spawn_command_line_async (command, NULL);
+		g_free (command);
+	}
+	else
+	{
+		SYNSHM(synaptics)->max_speed = delta;
+	}
+}
+
+void
+g_synaptics_set_min_speed(GSynaptics *synaptics, gdouble delta)
+{
+	GSynapticsPrivate *priv = G_SYNAPTICS_GET_PRIVATE (synaptics);
+	if (!g_synaptics_is_valid(synaptics))
+		return;
+
+	if (priv->synclient)
+	{
+		gchar *command;
+		command = g_strdup_printf ("synclient MinSpeed=%lf",
+			       		   delta);
+		/* TODO check that %lf is right */
+		g_spawn_command_line_async (command, NULL);
+		g_free (command);
+	}
+	else
+	{
+		SYNSHM(synaptics)->min_speed = delta;
+	}
+}
+
 void
 g_synaptics_set_circular_scroll_enabled (GSynaptics *synaptics, gboolean enable)
 {
@@ -704,7 +821,7 @@ g_synaptics_set_coasting_enabled (GSynaptics *synaptics, gboolean enable)
 	if (priv->synclient)
 	{
 		gchar *command;
-		command = g_strdup_printf ("synclient CoastingSpeedThreashold=%f",
+		command = g_strdup_printf ("synclient CoastingSpeedThreshold=%f",
 			       		   thresh);
 		g_spawn_command_line_async (command, NULL);
 		g_free (command);
