@@ -84,6 +84,9 @@ gboolean	g_synaptics_is_vertical_scroll_enabled  (GSynaptics *synaptics);
 gint		g_synaptics_vertical_scroll_delta       (GSynaptics *synaptics);
 gboolean	g_synaptics_is_edge_motion_enabled      (GSynaptics *synaptics);
 gboolean	g_synaptics_is_coasting_enabled         (GSynaptics *synaptics);
+gdouble		g_synaptics_accel_delta					(GSynaptics *synaptics);
+gdouble		g_synaptics_min_speed_delta				(GSynaptics *synaptics);
+gdouble		g_synaptics_max_speed_delta				(GSynaptics *synaptics);
 gboolean	g_synaptics_is_circular_scroll_enabled  (GSynaptics *synaptics);
 gint		g_synaptics_circular_scroll_delta       (GSynaptics *synaptics);
 ScrollTrigger	g_synaptics_circular_scroll_trigger     (GSynaptics *synaptics);
@@ -107,6 +110,12 @@ void		g_synaptics_set_horizontal_scroll_delta (GSynaptics *synaptics,
 							 gint        delta);
 void		g_synaptics_set_vertical_scroll_delta   (GSynaptics *synaptics,
 							 gint        delta);
+void		g_synaptics_set_accel					(GSynaptics *synaptics,
+							 gdouble		 delta);
+void		g_synaptics_set_max_speed				(GSynaptics *synaptics,
+							 gdouble		 delta);
+void		g_synaptics_set_min_speed				(GSynaptics *synaptics,
+							 gdouble		 delta);
 void		g_synaptics_set_circular_scroll_enabled (GSynaptics *synaptics,
 							 gboolean    enable);
 void		g_synaptics_set_edge_motion_enabled     (GSynaptics *synaptics,
