@@ -45,9 +45,54 @@ static void
 dialog_button_clicked_cb (GtkDialog *dialog, gint response_id) 
 {
 	if (response_id == GTK_RESPONSE_HELP)
-		g_warning("help");
+	{
+		GError *error = NULL;
+		GdkScreen *screen;
+		gchar *command;
+		const gchar *lang;
+		gchar *uri = NULL;
+		int i;
+		const gchar * const * langs = g_get_language_names ();
+
+		for (i = 0; langs[i]; i++)
+		{
+			lang = langs[i];
+			if (strchr (lang, '.'))
+				continue;
+
+			uri = g_build_filename(HELPDATADIR,
+					       "/gnome/help/" PACKAGE,
+					       lang,
+					       "/gsynaptics.xml",
+					       NULL);
+			if (g_file_test (uri, G_FILE_TEST_EXISTS))
+				break;
+			g_free (uri);
+			uri = NULL;
+		}
+
+		if (uri == NULL)
+		{
+			g_warning ("Cannot find help");
+			return;
+		}
+
+		command = g_strconcat ("gnome-help ghelp://", uri,  NULL);
+		g_free (uri);
+
+		screen = gtk_widget_get_screen (GTK_WIDGET (dialog));
+		gdk_spawn_command_line_on_screen (screen, command, &error);
+		if (error != NULL)
+		{
+			g_warning (error->message);
+			g_error_free (error);
+		}
+		g_free (command);
+	}
 	else
+	{
 		gtk_main_quit ();
+	}
 }
 
 static GladeXML *
@@ -245,6 +290,9 @@ cb_sensitivity_change (GtkRange *range, GtkScrollType scroll,
 	
 	synaptics = g_object_get_qdata (G_OBJECT(dialog), synaptics_quark);
 
+	if (value > 4.0) value = 4.0;
+	if (value < 0.0) value = 0.0;
+
 	g_synaptics_set_sensitivity (synaptics, (gint)value);
 	gconf_client_set_int (gconf, SENSITIVITY_KEY, (gint)value, NULL);
 
@@ -431,6 +479,45 @@ cb_cursor_movement_toggled (GtkToggleButton *button, GladeXML *dialog)
 	gconf_client_set_bool (gconf, EDGEMOTIONUSEALWAYS_KEY, value, NULL);
 }
 
+static gboolean
+cb_accel_change (GtkRange *range, GtkScrollType scroll,
+			     gdouble value, GladeXML *dialog)
+{
+	GSynaptics *synaptics;
+	
+	synaptics = g_object_get_qdata (G_OBJECT(dialog), synaptics_quark);
+
+	g_synaptics_set_accel(synaptics, value);
+
+	return FALSE;
+}
+
+static gboolean
+cb_min_speed_change (GtkRange *range, GtkScrollType scroll,
+			     gdouble value, GladeXML *dialog)
+{
+	GSynaptics *synaptics;
+	
+	synaptics = g_object_get_qdata (G_OBJECT(dialog), synaptics_quark);
+
+	g_synaptics_set_min_speed(synaptics, value);
+
+	return FALSE;
+}
+
+static gboolean
+cb_max_speed_change (GtkRange *range, GtkScrollType scroll,
+			     gdouble value, GladeXML *dialog)
+{
+	GSynaptics *synaptics;
+	
+	synaptics = g_object_get_qdata (G_OBJECT(dialog), synaptics_quark);
+
+	g_synaptics_set_max_speed(synaptics, value);
+
+	return FALSE;
+}
+
 static void
 setup_dialog (GladeXML *dialog)
 {
@@ -445,7 +532,7 @@ setup_dialog (GladeXML *dialog)
 	
 	synaptics = g_object_get_qdata (G_OBJECT(dialog), synaptics_quark);
 	
-	/* first pain */
+	/* first pane */
 	check = WID ("touchpad_check");
 	g_signal_connect (G_OBJECT (check), "toggled",
 			  G_CALLBACK (cb_touchpad_toggled), dialog);
@@ -461,7 +548,7 @@ setup_dialog (GladeXML *dialog)
 	g_signal_connect (G_OBJECT (scale), "change-value",
 			  G_CALLBACK (cb_sensitivity_change), dialog);
 
-	/* second pain (tapping) */
+	/* second pane (tapping) */
 	check = WID ("faster_tapping_check");
 	g_signal_connect (G_OBJECT (check), "toggled",
 			  G_CALLBACK (cb_fast_taps_toggled), dialog);
@@ -482,7 +569,7 @@ setup_dialog (GladeXML *dialog)
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check),
 	    			      value);
 
-	/* third pain (scroll) */
+	/* third pane (scroll) */
 	scale = WID ("vertical_scroll_scale");
 	num = g_synaptics_vertical_scroll_delta (synaptics);
 	gtk_range_set_value (GTK_RANGE (scale), num * -1);
@@ -534,6 +621,7 @@ setup_dialog (GladeXML *dialog)
 	button = WID ("trigger_right_edge_toggle");
 	g_signal_connect (G_OBJECT (button), "button_press_event",
 			  G_CALLBACK (cb_trigger_right_pressed),dialog);
+
 	button = WID ("trigger_top_left_corner_toggle");
 	g_signal_connect (G_OBJECT (button), "button_press_event",
 			  G_CALLBACK (cb_trigger_top_left_pressed),dialog);
@@ -565,6 +653,27 @@ setup_dialog (GladeXML *dialog)
 	g_signal_connect (G_OBJECT (check), "toggled",
 			  G_CALLBACK (cb_cursor_movement_toggled), dialog);
 
+	/* fourth pane */
+	scale = WID ("accel_scale");
+	/*num = g_synaptics_accel_delta (synaptics);*/
+	/* TODO figure out what to do with this g_synaptics_*_delta bit
+	 * or if it's even needed... */
+	/*gtk_range_set_value (GTK_RANGE (scale), num * -1);*/
+	g_signal_connect (G_OBJECT (scale), "change-value",
+			  G_CALLBACK (cb_accel_change), dialog);
+			  
+	scale = WID ("min_speed_scale");
+	num = g_synaptics_min_speed_delta (synaptics);
+	gtk_range_set_value (GTK_RANGE (scale), num * -1);
+	g_signal_connect (G_OBJECT (scale), "change-value",
+			  G_CALLBACK (cb_min_speed_change), dialog);
+			  	
+	scale = WID ("max_speed_scale");
+	num = g_synaptics_max_speed_delta (synaptics);
+	gtk_range_set_value (GTK_RANGE (scale), num * -1);
+	g_signal_connect (G_OBJECT (scale), "change-value",
+			  G_CALLBACK (cb_max_speed_change), dialog);
+			  
 	/* dialog window */
 	widget = WID ("gsynaptics_dialog");
 	g_signal_connect (G_OBJECT (widget), "response",
